.. battalion documentation master file, created by
   sphinx-quickstart on Fri Feb 27 22:21:03 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to battalion's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2

   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

